@@ -1,7 +1,7 @@
 libxmlVersion <-
 function()
 {
- v <- .Call("RS_XML_libxmlVersion")
+ v <- .Call("RS_XML_libxmlVersion", PACKAGE = "XML")
  v <- as.character(v)
  els <- substring(v, 1:nchar(v), 1:nchar(v))
  list(major=els[1], minor=paste(els[2:3],sep="", collapse=""), patch=paste(els[4:5], sep="", collapse=""))
@@ -10,4 +10,4 @@ function()
 
 setEntitySubstitution =
 function(val)
-  .Call("RS_XML_SubstituteEntitiesDefault", as.logical(val))
+  .Call("RS_XML_SubstituteEntitiesDefault", as.logical(val), PACKAGE = "XML")
